@@ -59,6 +59,7 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
         recursion_limit: int = 1,
         recursion_default: Any = {},
         faker_locale: Optional[Union[str, List[str]]] = None,
+        default_id_property_name: str = "id",
     ) -> None:
         super().__init__(
             source=source,
@@ -74,6 +75,7 @@ class OpenApiExecutors(OpenApiLibCore):  # pylint: disable=too-many-instance-att
             recursion_limit=recursion_limit,
             recursion_default=recursion_default,
             faker_locale=faker_locale,
+            default_id_property_name=default_id_property_name,
         )
         self.response_validation = response_validation
         self.disable_server_validation = disable_server_validation
